package gui.settings.dialog;

import gui.settings.dialog.page.SettingsPage;

import java.awt.Window;
import java.io.IOException;

import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import util.exception.CancelException;

public abstract class AbstractTreeSettingsDialog extends AbstractSettingsDialog {

	private static final long serialVersionUID = -3060698572704040161L;

	protected JTree tree;
	protected DefaultTreeModel treeModel;
	protected SettingsTreeNode rootNode;
	
	public AbstractTreeSettingsDialog(Window owner, String title) {
		super(owner, title);
		rootNode=new SettingsTreeNode(title);
		treeModel=new DefaultTreeModel(rootNode);
		tree=new JTree(treeModel);
		tree.addTreeSelectionListener(new TreeSelectionListener() {
			
			@Override
			public void valueChanged(TreeSelectionEvent e) {
				selectEntry() ;
			}
		});
		split.setLeftComponent(tree);
	}
	
	private void selectEntry() {
		if ( tree.getSelectionPath()!=null) {
			Object nodeContent=((DefaultMutableTreeNode) tree.getSelectionPath().getLastPathComponent()).getUserObject();
			if (nodeContent instanceof SettingsPage) {
				setCurrentSettingsPage((SettingsPage) nodeContent);
			}
		}
	}
	
	public void addSettingsPages(DefaultMutableTreeNode pagesRootNode) {
		rootNode.add(pagesRootNode);
		treeModel.nodeStructureChanged(rootNode);
	}
	
	@Override
	public void showDialog() throws CancelException, IOException {
		selectEntry() ;
		super.showDialog();
	}

}
