package gui.util.lookandfeel;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import gui.util.buttonhandler.ButtonHandler;

import javax.swing.JMenu;
import javax.swing.JOptionPane;
import javax.swing.JRadioButtonMenuItem;
import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;

import core.io.Application;

public class LAFMenuRestart extends JMenu {

	private static final long serialVersionUID = 8763592769772095663L;

	private Application app;
	private String name;
	private ButtonHandler hdl;
	private String localizedRestartMessage;
	
	public LAFMenuRestart(Application app, String settingsName,String localizedRestartMessage) {
		super("Look & Feel");
		this.app=app;
		this.name=settingsName;
		this.localizedRestartMessage=localizedRestartMessage;
		hdl=new ButtonHandler();
		LookAndFeelInfo[] lafs= UIManager.getInstalledLookAndFeels();
		String currLaF=app.getSettings().getString(settingsName);
		
		int index=-1;
		int i=0;
		for (LookAndFeelInfo laf:lafs) {
			addMenu(laf.getName(),laf.getClassName());
			if (currLaF.matches(laf.getClassName())){
				index=i;
			}
			i++;
		}
		addMenu("System Look & Feel", UIManager.getSystemLookAndFeelClassName());
		if (index==-1){
			hdl.setSelectedButton(hdl.getCount()-1);
		} else {
			hdl.setSelectedButton(index);
		}
		
	}
	
	private void addMenu(String text,String className) {
		LAFMenuItem item=new LAFMenuItem(text,className);
		hdl.add(item);
		item.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				changeLookandfeel(((LAFMenuItem)e.getSource()).getClassName());
				JOptionPane.showMessageDialog(null, localizedRestartMessage);
			}
		});
		add(item);
	}
	
	
	private void changeLookandfeel(String cn) {
		app.getSettings().set(name, cn);
	}
	private class LAFMenuItem extends JRadioButtonMenuItem {
		private static final long serialVersionUID = 6159552316197891173L;
		private String className;
		
		public LAFMenuItem(String text,String className) {
			super(text);
			this.className = className;
		}
		
		public String getClassName() {
			return className;
		}
	}
	
	public static void setLookAndFeel(Application app,String settingName){
		try{
			String laf=app.getSettings().getString(settingName);
			if (laf.equals("<system>")){
				UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
			} else {
				UIManager.setLookAndFeel(laf);
			}
			
		} catch (Exception e) {
		
			try{
				UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
			} catch (Exception ex) {
				try{
					UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
				} catch (Exception ex2) {
					throw new Error(ex2);
				}
			}
		}
	}

}
